==> sflphone_1.0.1.orig.tar.gz: sflphone-1.0.1/daemon/src/audio/recordable.cpp <==
/*
 *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
 *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#include "recordable.h"
#include "manager.h"

Recordable::Recordable() : recAudio(), recorder(&recAudio, Manager::instance().getMainBuffer())
{
    recAudio.setRecordingOption(AudioRecord::FILE_WAV, 8000, Manager::instance().audioPreference.getRecordpath());
}

Recordable::~Recordable()
{
    if (recAudio.isOpenFile())
        recAudio.closeFile();
}

void Recordable::initRecFileName(std::string filename)
{
    recAudio.initFileName(filename);
}

std::string Recordable::getFileName()
{
    return recAudio.getFileName();
}

void Recordable::setRecordingSmplRate(int smplRate)
{
    recAudio.setSndSamplingRate(smplRate);
}

int Recordable::getRecordingSmplRate() const
{
    return recAudio.getSndSamplingRate();
}

==> sflphone_1.2.2.orig.tar.gz: sflphone-1.2.2/daemon/src/audio/recordable.cpp <==
/*
 *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
 *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#include "recordable.h"
#include "manager.h"
#include "logger.h"

Recordable::Recordable() : recAudio_(), recorder_(&recAudio_, &Manager::instance().getMainBuffer())
{
    DEBUG("Set recording options: %s", Manager::instance().audioPreference.getRecordPath().c_str());
    recAudio_.setRecordingOption(AudioRecord::FILE_WAV, 8000, Manager::instance().audioPreference.getRecordPath());
}

Recordable::~Recordable()
{
    if (recAudio_.isOpenFile())
        recAudio_.closeFile();
}

void Recordable::initRecFilename(const std::string &filename)
{
    recAudio_.initFilename(filename);
}

std::string Recordable::getFilename() const
{
    return recAudio_.getFilename();
}

void Recordable::setRecordingSmplRate(int smplRate)
{
    recAudio_.setSndSamplingRate(smplRate);
}
